@@ -1,4 +1,4 @@
-/* $Id: cidr.c 2053 2008-05-31 02:19:17Z aturner $ */
+/* $Id: cidr.c 2074 2008-11-09 08:42:24Z aturner $ */
 
 /*
  * Copyright (c) 2001-2004 Aaron Turner.
@@ -241,7 +241,7 @@ cidr2cidr(char *cidr)
     memset(ebuf, '\0', EBUF_SIZE);
     strcpy(ebuf, "Unable to parse as a vaild CIDR: ");
     strlcat(ebuf, cidr, EBUF_SIZE);
-    errx(1, "%s", ebuf);
+    errx(-1, "%s", ebuf);
     return NULL;
 }
 
