@@ -1,4 +1,4 @@
-/* $Id: fakepcapnav.c 1897 2007-08-25 04:57:38Z aturner $ */
+/* $Id: fakepcapnav.c 2074 2008-11-09 08:42:24Z aturner $ */
 
 /*
  * Copyright (c) 2001-2005 Aaron Turner.
@@ -64,12 +64,12 @@ pcapnav_open_offline(const char *filename)
 
     pcapnav = (pcapnav_t *) malloc(sizeof(pcapnav_t));
     if (pcapnav == NULL) {
-        err(1, "malloc() error: unable to malloc pcapnav_t");
+        err(-1, "malloc() error: unable to malloc pcapnav_t");
     }
 
     pcapnav->pcap = pcap_open_offline(filename, errbuf);
     if (pcapnav->pcap == NULL) {
-        errx(1, "Error opening pcap file %s: %s", filename, errbuf);
+        errx(-1, "Error opening pcap file %s: %s", filename, errbuf);
     }
 
     return (pcapnav);
