@@ -1,4 +1,4 @@
-/* $Id: get.c 1991 2008-04-26 22:22:05Z aturner $ */
+/* $Id: get.c 2096 2009-01-04 20:48:34Z aturner $ */
 
 /*
  * Copyright (c) 2001-2005 Aaron Turner.
@@ -127,7 +127,7 @@ get_l2protocol(const u_char *pktdata, const int datalen, const int datalink)
         break;
 
     default:
-        errx(1, "Unable to process unsupported DLT type: %s (0x%x)", 
+        errx(-1, "Unable to process unsupported DLT type: %s (0x%x)", 
              pcap_datalink_val_to_description(datalink), datalink);
 
     }
@@ -143,7 +143,6 @@ int
 get_l2len(const u_char *pktdata, const int datalen, const int datalink)
 {
     eth_hdr_t *eth_hdr;
-    u_int16_t ether_type;
     
     assert(pktdata);
     assert(datalen);
@@ -176,7 +175,7 @@ get_l2len(const u_char *pktdata, const int datalen, const int datalink)
         break;
 
     default:
-        errx(1, "Unable to process unsupported DLT type: %s (0x%x)", 
+        errx(-1, "Unable to process unsupported DLT type: %s (0x%x)", 
              pcap_datalink_val_to_description(datalink), datalink);
         break;
     }
