@@ -1,4 +1,4 @@
-/* $Id: list.c 1897 2007-08-25 04:57:38Z aturner $ */
+/* $Id: list.c 2074 2008-11-09 08:42:24Z aturner $ */
 
 /*
  * Copyright (c) 2001-2004 Aaron Turner.
@@ -82,7 +82,7 @@ parse_list(tcpr_list_t ** listdata, char *ourstr)
     /* compile the regex first */
     if ((rcode = regcomp(&preg, regex, REG_EXTENDED | REG_NOSUB)) != 0) {
         regerror(rcode, &preg, ebuf, sizeof(ebuf));
-        errx(1, "Unable to compile regex (%s): %s", regex, ebuf);
+        errx(-1, "Unable to compile regex (%s): %s", regex, ebuf);
     }
 
     /* first iteration */
