@@ -1,4 +1,4 @@
-/* $Id: sendpacket.h 2012 2008-05-03 18:54:02Z aturner $ */
+/* $Id: sendpacket.h 2114 2009-01-08 17:37:22Z aturner $ */
 
 /*
  * Copyright (c) 2006 Aaron Turner.
@@ -36,14 +36,31 @@
 #include <netpacket/packet.h>
 #endif
 
+#ifdef HAVE_LIBDNET
+/* need to undef these which are pulled in via defines.h, prior to importing dnet.h */
+#undef icmp_id
+#undef icmp_seq
+#undef icmp_data
+#undef icmp_mask
+#include <dnet.h>
+#endif
+
 #ifndef _SENDPACKET_H_
 #define _SENDPACKET_H_
 
+enum sendpacket_type_t {
+    SP_TYPE_LIBNET,
+    SP_TYPE_LIBDNET,
+    SP_TYPE_LIBPCAP,
+    SP_TYPE_BPF,
+    SP_TYPE_PF_PACKET
+};
+
 union sendpacket_handle {
     pcap_t *pcap;
     int fd;
-#ifdef HAVE_LIBNET
-    libnet_t *lnet;
+#ifdef HAVE_LIBDNET
+    eth_t *ldnet;
 #endif
 };
 
@@ -60,6 +77,7 @@ struct sendpacket_s {
     COUNTER sent;
     COUNTER bytes_sent;
     COUNTER attempt;
+    enum sendpacket_type_t handle_type;
     union sendpacket_handle handle;
     struct tcpr_ether_addr ether;
 #ifdef HAVE_PF_PACKET
@@ -76,6 +94,7 @@ char *sendpacket_getstat(sendpacket_t *);
 sendpacket_t *sendpacket_open(const char *, char *, tcpr_dir_t);
 struct tcpr_ether_addr *sendpacket_get_hwaddr(sendpacket_t *);
 int sendpacket_get_dlt(sendpacket_t *);
+const char *sendpacket_get_method();
 
 #endif /* _SENDPACKET_H_ */
 
