@@ -1,4 +1,4 @@
-/* $Id: xX.c 1897 2007-08-25 04:57:38Z aturner $ */
+/* $Id: xX.c 2074 2008-11-09 08:42:24Z aturner $ */
 
 /*
  * Copyright (c) 2001-2004 Aaron Turner.
@@ -98,14 +98,14 @@ parse_xX_str(tcpr_xX_t *xX, char *str, tcpr_bpf_t *bpf)
 
 
     default:
-        errx(1, "Invalid -%c option: %c", xX->mode, *str);
+        errx(-1, "Invalid -%c option: %c", xX->mode, *str);
         break;
     }
 
     if (xX->mode == 'X') {          /* run in exclude mode */
         out += xXExclude;
         if (bpf->filter != NULL)
-            err(1, "Using a BPF filter with -X doesn't work.\n"
+            err(-1, "Using a BPF filter with -X doesn't work.\n"
                 "Try using -xF:\"not <filter>\" instead");
     }
 
