@@ -1,4 +1,4 @@
-/* $Id: edit_packet.c 2097 2009-01-04 20:58:47Z aturner $ */
+/* $Id: edit_packet.c 2211 2009-02-18 02:48:04Z aturner $ */
 
 /*
  * Copyright (c) 2001-2007 Aaron Turner.
@@ -171,11 +171,12 @@ untrunc_packet(tcpedit_t *tcpedit, struct pcap_pkthdr *pkthdr,
     assert(tcpedit);
     assert(pkthdr);
     assert(pktdata);
-    assert(ip_hdr);
 
     /* if actual len == cap len or there's no IP header, don't do anything */
     if ((pkthdr->caplen == pkthdr->len) || (ip_hdr == NULL)) {
-        return(0);
+        /* unless we're in MTU truncate mode */
+        if (! tcpedit->mtu_truncate)
+            return(0);
     }
     
     if ((l2len = layer2len(tcpedit)) < 0) {
@@ -205,6 +206,20 @@ untrunc_packet(tcpedit_t *tcpedit, struct pcap_pkthdr *pkthdr,
             ip_hdr->ip_len = htons(pkthdr->caplen - l2len);
         pkthdr->len = pkthdr->caplen;
     }
+    else if (tcpedit->mtu_truncate) {
+        if (pkthdr->len > (tcpedit->mtu + l2len)) {
+            /* first truncate the packet */
+            pkthdr->len = pkthdr->caplen = l2len + tcpedit->mtu;
+            
+            /* if ip_hdr exists, update the length */
+            if (ip_hdr != NULL) {
+                ip_hdr->ip_len = htons(tcpedit->mtu);
+            } else {
+                 /* for non-IP frames, don't try to fix checksums */  
+                return 0;
+            }
+        }
+    }
     else {
         tcpedit_seterr(tcpedit, "Invalid fixlen value: 0x%x", tcpedit->fixlen);
         return -1;
@@ -515,6 +530,9 @@ rewrite_iparp(tcpedit_t *tcpedit, arp_hdr_t *arp_hdr, int cache_mode)
     u_int32_t newip = 0;
     tcpr_cidrmap_t *cidrmap1 = NULL, *cidrmap2 = NULL;
     int didsrc = 0, diddst = 0, loop = 1;
+#ifdef FORCE_ALIGN
+    u_int32_t iptemp;
+#endif
 
     assert(tcpedit);
     assert(arp_hdr);
@@ -546,7 +564,14 @@ rewrite_iparp(tcpedit_t *tcpedit, arp_hdr_t *arp_hdr, int cache_mode)
         add_hdr += sizeof(arp_hdr_t) + arp_hdr->ar_hln;
         ip1 = (u_int32_t *)add_hdr;
         add_hdr += arp_hdr->ar_pln + arp_hdr->ar_hln;
+#ifdef FORCE_ALIGN
+        /* copy IP2 to a temporary buffer for processing */
+        memcpy(&iptemp, add_hdr, sizeof(u_int32_t));
+        ip2 = &iptemp;
+#else
         ip2 = (u_int32_t *)add_hdr;
+#endif
+        
 
         /* loop through the cidrmap to rewrite */
         do {
@@ -576,7 +601,11 @@ rewrite_iparp(tcpedit_t *tcpedit, arp_hdr_t *arp_hdr, int cache_mode)
                     didsrc = 1;
                 }
             }
-            
+
+#ifdef FORCE_ALIGN
+            /* copy temporary IP to IP2 location in buffer */
+            memcpy(add_hdr, &iptemp, sizeof(u_int32_t));
+#endif
 
             /*
              * loop while we haven't modified both src/dst AND
