@@ -1,4 +1,4 @@
-/* $Id: parse_args.c 2109 2009-01-07 20:15:25Z aturner $ */
+/* $Id: parse_args.c 2211 2009-02-18 02:48:04Z aturner $ */
 
 /*
  * Copyright (c) 2006 Aaron Turner.
@@ -148,6 +148,10 @@ tcpedit_post_args(tcpedit_t **tcpedit_ex) {
     if (HAVE_OPT(MTU))
         tcpedit->mtu = OPT_VALUE_MTU;
         
+    /* --mtu-trunc */
+    if (HAVE_OPT(MTU_TRUNC))
+        tcpedit->mtu_truncate = 1;
+        
     /* --skipbroadcast */
     if (HAVE_OPT(SKIPBROADCAST))
         tcpedit->skip_broadcast = 1;
