@@ -1,4 +1,4 @@
-/* $Id: raw.c 1911 2007-10-23 21:53:34Z aturner $ */
+/* $Id: raw.c 2105 2009-01-07 05:48:32Z aturner $ */
 
 /*
  * Copyright (c) 2006-2007 Aaron Turner.
@@ -207,14 +207,10 @@ dlt_raw_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
  * Returns: total packet len or TCPEDIT_ERROR
  */
 int 
-dlt_raw_encode(tcpeditdlt_t *ctx, u_char **packet_ex, int pktlen, _U_ tcpr_dir_t dir)
+dlt_raw_encode(tcpeditdlt_t *ctx, u_char *packet, int pktlen, _U_ tcpr_dir_t dir)
 {
-    u_char *packet;
     assert(ctx);
-    assert(packet_ex);
     assert(pktlen > 0);
-    
-    packet = *packet_ex;
     assert(packet);
     
     tcpedit_seterr(ctx->tcpedit, "%s", "DLT_RAW plugin does not support packet encoding");
