@@ -1,4 +1,4 @@
-/* $Id: user.c 1893 2007-08-10 04:24:50Z aturner $ */
+/* $Id: user.c 2116 2009-01-08 19:10:14Z aturner $ */
 
 /*
  * Copyright (c) 2006-2007 Aaron Turner.
@@ -225,28 +225,23 @@ dlt_user_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
  * Returns: total packet len or TCPEDIT_ERROR
  */
 int 
-dlt_user_encode(tcpeditdlt_t *ctx, u_char **packet_ex, int pktlen, tcpr_dir_t dir)
+dlt_user_encode(tcpeditdlt_t *ctx, u_char *packet, int pktlen, tcpr_dir_t dir)
 {
-    u_char *packet;
-    int l2len;
     user_config_t *config;
     tcpeditdlt_plugin_t *plugin;
     u_char tmpbuff[MAXPACKET];
 
     assert(ctx);
-    assert(packet_ex);
     assert(pktlen > 0);
-    
-    packet = *packet_ex;
     assert(packet);
     
     plugin = tcpedit_dlt_getplugin(ctx, dlt_value);
     config = plugin->config;
 
     /* Make room for our new l2 header if l2len != config->length */
-    if (l2len > config->length) {
+    if (ctx->l2len > config->length) {
         memmove(packet + config->length, packet + ctx->l2len, pktlen - ctx->l2len);
-    } else if (l2len < config->length) {
+    } else if (ctx->l2len < config->length) {
         memcpy(tmpbuff, packet, pktlen);
         memcpy(packet + config->length, (tmpbuff + ctx->l2len), pktlen - ctx->l2len);
     }
