@@ -1,4 +1,4 @@
-/* $Id: tcpedit-int.h 2109 2009-01-07 20:15:25Z aturner $ */
+/* $Id: tcpedit-int.h 2211 2009-02-18 02:48:04Z aturner $ */
 
 /*
  * Copyright (c) 2006-2007 Aaron Turner.
@@ -130,7 +130,7 @@ struct tcpedit_s {
     tcpedit_portmap_t *portmap;
     
     int mtu;                /* Deal with different MTU's */
-    int maxpacket;          /* L2 header + MTU */
+    int mtu_truncate;       /* Should frames > MTU be truncated? */
 };
 
 #define tcpedit_seterr(x, y, ...) __tcpedit_seterr(x, __FUNCTION__, __LINE__, __FILE__, y, __VA_ARGS__)
