@@ -1,4 +1,4 @@
-/* $Id: tcpedit.c 2109 2009-01-07 20:15:25Z aturner $ */
+/* $Id: tcpedit.c 2211 2009-02-18 02:48:04Z aturner $ */
 
 /*
  * Copyright (c) 2001-2007 Aaron Turner.
@@ -157,12 +157,12 @@ tcpedit_packet(tcpedit_t *tcpedit, struct pcap_pkthdr **pkthdr,
             needtorecalc += retval;
         }
 
-        /* Untruncate packet? Only works for IP packets */
-        if (tcpedit->fixlen) {
-            if ((retval = untrunc_packet(tcpedit, *pkthdr, packet, ip_hdr)) < 0)
-                return TCPEDIT_ERROR;
-            needtorecalc += retval;
-        }
+    }
+    /* (Un)truncate or MTU truncate packet? */
+    if (tcpedit->fixlen || tcpedit->mtu_truncate) {
+        if ((retval = untrunc_packet(tcpedit, *pkthdr, packet, ip_hdr)) < 0)
+            return TCPEDIT_ERROR;
+        needtorecalc += retval;
     }
     
     /* rewrite IP addresses in IPv4 or ARP */
